@@ -4,7 +4,7 @@ DISTRIB="$1"
 TDE_VERSION="$2"
 ARCH="$3"
 
-[ -z "${TDE_VERSION}" ] && TDE_VERSION="14.1.0"
+[ -z "${TDE_VERSION}" ] && TDE_VERSION="14.1.1"
 [ -z "${ARCH}" ] && ARCH="x86_64"
 [ -x /usr/bin/podman ] && DOCKER=podman || DOCKER=docker
 
@@ -18,6 +18,7 @@ chmod 777 "${HOME}/rpmbuild/RPMS/RPMS${DIST}.tde-${TDE_VERSION}" "${HOME}/rpmbui
 
 case "${TDE_VERSION}" in
   "14.0."*) TDE_BRANCH="r14.0.x";;
+  "14.1."*) TDE_BRANCH="r14.1.x";;
   *) TDE_BRANCH="master";;
 esac
 
@@ -33,8 +34,10 @@ ${DOCKER} run -ti --rm \
   -e TDE_BRANCH=${TDE_BRANCH} \
   -w /home/trinity/tde/${TDE_BRANCH}/tde/packaging/redhat \
   -v ${HOME}/.gnupg:/home/trinity/.gnupg \
+  -v ${HOME}/tde/3rdparty:/home/trinity/tde/3rdparty \
   -v ${HOME}/tde/master:/home/trinity/tde/master \
   -v ${HOME}/tde/r14.0.x:/home/trinity/tde/r14.0.x \
+  -v ${HOME}/tde/r14.1.x:/home/trinity/tde/r14.1.x \
   -v ${HOME}/tde/patches:/home/trinity/tde/patches \
   -v ${HOME}/tde/tarballs:/home/trinity/tde/tarballs \
   -v ${HOME}/rpmbuild/RPMS/RPMS${DIST}.tde-${TDE_VERSION}:/home/trinity/rpmbuild/RPMS.tde-${TDE_VERSION} \
